# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class MrScalar(pulumi.CustomResource):
    additional_info: pulumi.Output[str]
    additional_primary_security_groups: pulumi.Output[list]
    additional_replica_security_groups: pulumi.Output[list]
    applications: pulumi.Output[list]
    availability_zones: pulumi.Output[list]
    bootstrap_actions_files: pulumi.Output[list]
    cluster_id: pulumi.Output[str]
    """
    The MrScaler cluster id.
    """
    configurations_files: pulumi.Output[list]
    core_desired_capacity: pulumi.Output[float]
    core_ebs_block_devices: pulumi.Output[list]
    core_ebs_optimized: pulumi.Output[bool]
    core_instance_types: pulumi.Output[list]
    core_lifecycle: pulumi.Output[str]
    core_max_size: pulumi.Output[float]
    core_min_size: pulumi.Output[float]
    core_scaling_down_policies: pulumi.Output[list]
    core_scaling_up_policies: pulumi.Output[list]
    custom_ami_id: pulumi.Output[str]
    description: pulumi.Output[str]
    """
    The MrScaler description.
    """
    ebs_root_volume_size: pulumi.Output[float]
    ec2_key_name: pulumi.Output[str]
    expose_cluster_id: pulumi.Output[bool]
    instance_weights: pulumi.Output[list]
    job_flow_role: pulumi.Output[str]
    keep_job_flow_alive: pulumi.Output[bool]
    log_uri: pulumi.Output[str]
    managed_primary_security_group: pulumi.Output[str]
    managed_replica_security_group: pulumi.Output[str]
    master_ebs_block_devices: pulumi.Output[list]
    master_ebs_optimized: pulumi.Output[bool]
    master_instance_types: pulumi.Output[list]
    master_lifecycle: pulumi.Output[str]
    name: pulumi.Output[str]
    """
    The MrScaler name.
    """
    output_cluster_id: pulumi.Output[str]
    provisioning_timeout: pulumi.Output[dict]
    region: pulumi.Output[str]
    """
    The MrScaler region.
    """
    release_label: pulumi.Output[str]
    repo_upgrade_on_boot: pulumi.Output[str]
    retries: pulumi.Output[float]
    scheduled_tasks: pulumi.Output[list]
    security_config: pulumi.Output[str]
    service_access_security_group: pulumi.Output[str]
    service_role: pulumi.Output[str]
    steps_files: pulumi.Output[list]
    strategy: pulumi.Output[str]
    """
    The MrScaler strategy. Allowed values are `new` `clone` and `wrap`.
    """
    tags: pulumi.Output[list]
    task_desired_capacity: pulumi.Output[float]
    task_ebs_block_devices: pulumi.Output[list]
    task_ebs_optimized: pulumi.Output[bool]
    task_instance_types: pulumi.Output[list]
    task_lifecycle: pulumi.Output[str]
    task_max_size: pulumi.Output[float]
    task_min_size: pulumi.Output[float]
    task_scaling_down_policies: pulumi.Output[list]
    task_scaling_up_policies: pulumi.Output[list]
    termination_protected: pulumi.Output[bool]
    visible_to_all_users: pulumi.Output[bool]
    def __init__(__self__, resource_name, opts=None, additional_info=None, additional_primary_security_groups=None, additional_replica_security_groups=None, applications=None, availability_zones=None, bootstrap_actions_files=None, cluster_id=None, configurations_files=None, core_desired_capacity=None, core_ebs_block_devices=None, core_ebs_optimized=None, core_instance_types=None, core_lifecycle=None, core_max_size=None, core_min_size=None, core_scaling_down_policies=None, core_scaling_up_policies=None, custom_ami_id=None, description=None, ebs_root_volume_size=None, ec2_key_name=None, expose_cluster_id=None, instance_weights=None, job_flow_role=None, keep_job_flow_alive=None, log_uri=None, managed_primary_security_group=None, managed_replica_security_group=None, master_ebs_block_devices=None, master_ebs_optimized=None, master_instance_types=None, master_lifecycle=None, name=None, provisioning_timeout=None, region=None, release_label=None, repo_upgrade_on_boot=None, retries=None, scheduled_tasks=None, security_config=None, service_access_security_group=None, service_role=None, steps_files=None, strategy=None, tags=None, task_desired_capacity=None, task_ebs_block_devices=None, task_ebs_optimized=None, task_instance_types=None, task_lifecycle=None, task_max_size=None, task_min_size=None, task_scaling_down_policies=None, task_scaling_up_policies=None, termination_protected=None, visible_to_all_users=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Spotinst AWS MrScaler resource.

        ## Provisioning Timeout (Clone, New strategies)

        * `timeout` - (Optional) The amount of time (minutes) after which the cluster is automatically terminated if it's still in provisioning status. Minimum: '15'.
        * `timeout_action` - (Optional) The action to take if the timeout is exceeded. Valid values: `terminate`, `terminateAndRetry`.

        <a id="cluster-config"></a>
        ## Cluster Configuration (New strategy only)

        * `log_uri` - (Optional) The path to the Amazon S3 location where logs for this cluster are stored.
        * `additional_info` - (Optional) This is meta information about third-party applications that third-party vendors use for testing purposes.
        * `security_config` - (Optional) The name of the security configuration applied to the cluster.
        * `service_role` - (Optional) The IAM role that will be assumed by the Amazon EMR service to access AWS resources on your behalf.
        * `job_flow_role` - (Optional) The IAM role that was specified when the job flow was launched. The EC2 instances of the job flow assume this role.
        * `termination_protected` - (Optional) Specifies whether the Amazon EC2 instances in the cluster are protected from termination by API calls, user intervention, or in the event of a job-flow error.
        * `keep_job_flow_alive` - (Optional) Specifies whether the cluster should remain available after completing all steps.

        <a id="task-group"></a>
        ## Task Group (Wrap, Clone, and New strategies)

        * `task_instance_types` - (Required) The MrScaler instance types for the task nodes.
        * `task_target` - (Required) amount of instances in task group.
        * `task_maximum` - (Optional) maximal amount of instances in task group.
        * `task_minimum` - (Optional) The minimal amount of instances in task group.
        * `task_lifecycle` - (Required) The MrScaler lifecycle for instances in task group. Allowed values are 'SPOT' and 'ON_DEMAND'.
        * `task_ebs_optimized` - (Optional) EBS Optimization setting for instances in group.
        * `task_ebs_block_device` - (Required) This determines the ebs configuration for your task group instances. Only a single block is allowed.
            * `volumes_per_instance` - (Optional; Default 1) Amount of volumes per instance in the task group.
            * `volume_type` - (Required) volume type. Allowed values are 'gp2', 'io1' and others.
            * `size_in_gb` - (Required) Size of the volume, in GBs.
            * `iops` - (Optional) IOPS for the volume. Required in some volume types, such as io1.

        <a id="core-group"></a>
        ## Core Group (Clone, New strategies)

        * `core_instance_types` - (Required) The MrScaler instance types for the core nodes.
        * `core_target` - (Required) amount of instances in core group.
        * `core_maximum` - (Optional) maximal amount of instances in core group.
        * `core_minimum` - (Optional) The minimal amount of instances in core group.
        * `core_lifecycle` - (Required) The MrScaler lifecycle for instances in core group. Allowed values are 'SPOT' and 'ON_DEMAND'.
        * `core_ebs_optimized` - (Optional) EBS Optimization setting for instances in group.
        * `core_ebs_block_device` - (Required) This determines the ebs configuration for your core group instances. Only a single block is allowed.
            * `volumes_per_instance` - (Optional; Default 1) Amount of volumes per instance in the core group.
            * `volume_type` - (Required) volume type. Allowed values are 'gp2', 'io1' and others.
            * `size_in_gb` - (Required) Size of the volume, in GBs.
            * `iops` - (Optional) IOPS for the volume. Required in some volume types, such as io1.

        <a id="master-group"></a>
        ## Master Group (Clone, New strategies)

        * `master_instance_types` - (Required) The MrScaler instance types for the master nodes.
        * `master_lifecycle` - (Required) The MrScaler lifecycle for instances in master group. Allowed values are 'SPOT' and 'ON_DEMAND'.
        * `master_ebs_optimized` - (Optional) EBS Optimization setting for instances in group.
        * `master_ebs_block_device` - (Required) This determines the ebs configuration for your master group instances. Only a single block is allowed.
            * `volumes_per_instance` - (Optional; Default 1) Amount of volumes per instance in the master group.
            * `volume_type` - (Required) volume type. Allowed values are 'gp2', 'io1' and others.
            * `size_in_gb` - (Required) Size of the volume, in GBs.
            * `iops` - (Optional) IOPS for the volume. Required in some volume types, such as io1.

        <a id="tags"></a>
        ## Tags (Clone, New strategies)

        * `tags` - (Optional) A list of tags to assign to the resource. You may define multiple tags.
            * `key` - (Required) Tag key.
            * `value` - (Required) Tag value.

        <a id="Optional Compute Parameters"></a>  
        ## Optional Compute Parameters (New strategy)

        * `managed_primary_security_group` - (Optional) EMR Managed Security group that will be set to the primary instance group.
        * `managed_replica_security_group` - (Optional) EMR Managed Security group that will be set to the replica instance group.
        * `service_access_security_group` - (Optional) The identifier of the Amazon EC2 security group for the Amazon EMR service to access clusters in VPC private subnets.
        * `additional_primary_security_groups` - (Optional) A list of additional Amazon EC2 security group IDs for the master node.
        * `additional_replica_security_groups` - (Optional) A list of additional Amazon EC2 security group IDs for the core and task nodes.
        * `custom_ami_id` - (Optional) The ID of a custom Amazon EBS-backed Linux AMI if the cluster uses a custom AMI.
        * `repo_upgrade_on_boot` - (Optional) Applies only when `custom_ami_id` is used. Specifies the type of updates that are applied from the Amazon Linux AMI package repositories when an instance boots using the AMI. Possible values include: `SECURITY`, `NONE`.
        * `ec2_key_name` - (Optional) The name of an Amazon EC2 key pair that can be used to ssh to the master node.
        * `applications` - (Optional) A case-insensitive list of applications for Amazon EMR to install and configure when launching the cluster
            * `args` - (Optional) Arguments for EMR to pass to the application.
            * `name` - (Required) The application name.
            * `version`- (Optional)T he version of the application.
        * `instance_weights` - (Optional) Describes the instance and weights. Check out [Elastigroup Weighted Instances](https://api.spotinst.com/elastigroup-for-aws/concepts/general-concepts/elastigroup-capacity-instances-or-weighted) for more info.
            * `instance_type` - (Required) The type of the instance.
            * `weighted_capacity` - (Required) The weight given to the associated instance type. 

        <a id="availability-zone"></a>
        ## Availability Zones (Clone, New strategies)

        * `availability_zones` - (Required in Clone) List of AZs and their subnet Ids. See example above for usage.

        <a id="configurations"></a>
        ## Configurations (Clone, New strategies)

        * `configurations_file` - (Optional) Describes path to S3 file containing description of configurations. [More Information](https://api.spotinst.com/elastigroup-for-aws/services-integrations/elastic-mapreduce/import-an-emr-cluster/advanced/)
            * `bucket` - (Required) S3 Bucket name for configurations.
            * `key`- (Required) S3 key for configurations.
            
        <a id="steps"></a>
        ## Steps (Clone, New strategies)

        * `steps_file` - (Optional) Steps from S3.
            * `bucket` - (Required) S3 Bucket name for steps.
            * `key`- (Required) S3 key for steps.
            
        <a id="boostrap-actions"></a>
        ## Bootstrap Actions (Clone, New strategies)   

        * `bootstrap_actions_file` - (Optional) Describes path to S3 file containing description of bootstrap actions. [More Information](https://api.spotinst.com/elastigroup-for-aws/services-integrations/elastic-mapreduce/import-an-emr-cluster/advanced/)
            * `bucket` - (Required) S3 Bucket name for bootstrap actions.
            * `key`- (Required) S3 key for bootstrap actions.

        <a id="scaling-policy"></a>
        ## Scaling Policies

        Possible task group scaling policies (Wrap, Clone, and New strategies):
        * `task_scaling_up_policy`
        * `task_scaling_down_policy`

        Possible core group scaling policies (Clone, New strategies):
        * `core_scaling_up_policy`
        * `core_scaling_down_policy`

        Each `*_scaling_*_policy` supports the following:

        * `policy_name` - (Required) The name of the policy.
        * `metric_name` - (Required) The name of the metric, with or without spaces.
        * `statistic` - (Required) The metric statistics to return. For information about specific statistics go to [Statistics](http://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/index.html?CHAP_TerminologyandKeyConcepts.html#Statistic) in the Amazon CloudWatch Developer Guide.
        * `unit` - (Required) The unit for the metric.
        * `threshold` - (Required) The value against which the specified statistic is compared.
        * `adjustment` - (Optional) The number of instances to add/remove to/from the target capacity when scale is needed.
        * `min_target_capacity` - (Optional) Min target capacity for scale up.
        * `max_target_capacity` - (Optional) Max target capacity for scale down.
        * `namespace` - (Required) The namespace for the metric.
        * `operator` - (Required) The operator to use. Allowed values are : 'gt', 'gte', 'lt' , 'lte'.
        * `evaluation_periods` - (Required) The number of periods over which data is compared to the specified threshold.
        * `period` - (Required) The granularity, in seconds, of the returned datapoints. Period must be at least 60 seconds and must be a multiple of 60.
        * `cooldown` - (Required) The amount of time, in seconds, after a scaling activity completes and before the next scaling activity can start.
        * `dimensions` - (Optional) A mapping of dimensions describing qualities of the metric.
        * `minimum` - (Optional) The minimum to set when scale is needed.
        * `maximum` - (Optional) The maximum to set when scale is needed.
        * `target` - (Optional) The number of instances to set when scale is needed.
        * `action_type` - (Required) The type of action to perform. Allowed values are : 'adjustment', 'setMinTarget', 'setMaxTarget', 'updateCapacity', 'percentageAdjustment'

        <a id="scheduled-task"></a>
        ## Scheduled Tasks

        * `scheduled_task` - (Optional) An array of scheduled tasks.
        * `is_enabled` - (Optional) Enable/Disable the specified scheduling task.
        * `task_type` - (Required) The type of task to be scheduled. Valid values: `setCapacity`.
        * `instance_group_type` - (Required) Select the EMR instance groups to execute the scheduled task on. Valid values: `task`.
        * `cron` - (Required) A cron expression representing the schedule for the task.
        * `desired_capacity` - (Optional) New desired capacity for the elastigroup.
        * `min_capacity` - (Optional) New min capacity for the elastigroup.
        * `max_capacity` - (Optional) New max capacity for the elastigroup.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-spotinst/blob/master/website/docs/r/mrscaler_aws.html.markdown.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cluster_id: The MrScaler cluster id.
        :param pulumi.Input[str] description: The MrScaler description.
        :param pulumi.Input[str] name: The MrScaler name.
        :param pulumi.Input[str] region: The MrScaler region.
        :param pulumi.Input[str] strategy: The MrScaler strategy. Allowed values are `new` `clone` and `wrap`.

        The **applications** object supports the following:

          * `args` (`pulumi.Input[list]`)
          * `name` (`pulumi.Input[str]`) - The MrScaler name.
          * `version` (`pulumi.Input[str]`)

        The **bootstrap_actions_files** object supports the following:

          * `bucket` (`pulumi.Input[str]`)
          * `key` (`pulumi.Input[str]`)

        The **configurations_files** object supports the following:

          * `bucket` (`pulumi.Input[str]`)
          * `key` (`pulumi.Input[str]`)

        The **core_ebs_block_devices** object supports the following:

          * `iops` (`pulumi.Input[float]`)
          * `sizeInGb` (`pulumi.Input[float]`)
          * `volumeType` (`pulumi.Input[str]`)
          * `volumesPerInstance` (`pulumi.Input[float]`)

        The **core_scaling_down_policies** object supports the following:

          * `actionType` (`pulumi.Input[str]`)
          * `adjustment` (`pulumi.Input[str]`)
          * `cooldown` (`pulumi.Input[float]`)
          * `dimensions` (`pulumi.Input[dict]`)
          * `evaluationPeriods` (`pulumi.Input[float]`)
          * `maxTargetCapacity` (`pulumi.Input[str]`)
          * `maximum` (`pulumi.Input[str]`)
          * `metricName` (`pulumi.Input[str]`)
          * `minTargetCapacity` (`pulumi.Input[str]`)
          * `minimum` (`pulumi.Input[str]`)
          * `namespace` (`pulumi.Input[str]`)
          * `operator` (`pulumi.Input[str]`)
          * `period` (`pulumi.Input[float]`)
          * `policyName` (`pulumi.Input[str]`)
          * `statistic` (`pulumi.Input[str]`)
          * `target` (`pulumi.Input[str]`)
          * `threshold` (`pulumi.Input[float]`)
          * `unit` (`pulumi.Input[str]`)

        The **core_scaling_up_policies** object supports the following:

          * `actionType` (`pulumi.Input[str]`)
          * `adjustment` (`pulumi.Input[str]`)
          * `cooldown` (`pulumi.Input[float]`)
          * `dimensions` (`pulumi.Input[dict]`)
          * `evaluationPeriods` (`pulumi.Input[float]`)
          * `maxTargetCapacity` (`pulumi.Input[str]`)
          * `maximum` (`pulumi.Input[str]`)
          * `metricName` (`pulumi.Input[str]`)
          * `minTargetCapacity` (`pulumi.Input[str]`)
          * `minimum` (`pulumi.Input[str]`)
          * `namespace` (`pulumi.Input[str]`)
          * `operator` (`pulumi.Input[str]`)
          * `period` (`pulumi.Input[float]`)
          * `policyName` (`pulumi.Input[str]`)
          * `statistic` (`pulumi.Input[str]`)
          * `target` (`pulumi.Input[str]`)
          * `threshold` (`pulumi.Input[float]`)
          * `unit` (`pulumi.Input[str]`)

        The **instance_weights** object supports the following:

          * `instanceType` (`pulumi.Input[str]`)
          * `weightedCapacity` (`pulumi.Input[float]`)

        The **master_ebs_block_devices** object supports the following:

          * `iops` (`pulumi.Input[float]`)
          * `sizeInGb` (`pulumi.Input[float]`)
          * `volumeType` (`pulumi.Input[str]`)
          * `volumesPerInstance` (`pulumi.Input[float]`)

        The **provisioning_timeout** object supports the following:

          * `timeout` (`pulumi.Input[float]`)
          * `timeoutAction` (`pulumi.Input[str]`)

        The **scheduled_tasks** object supports the following:

          * `cron` (`pulumi.Input[str]`)
          * `desired_capacity` (`pulumi.Input[str]`)
          * `instanceGroupType` (`pulumi.Input[str]`)
          * `isEnabled` (`pulumi.Input[bool]`)
          * `maxCapacity` (`pulumi.Input[str]`)
          * `minCapacity` (`pulumi.Input[str]`)
          * `taskType` (`pulumi.Input[str]`)

        The **steps_files** object supports the following:

          * `bucket` (`pulumi.Input[str]`)
          * `key` (`pulumi.Input[str]`)

        The **tags** object supports the following:

          * `key` (`pulumi.Input[str]`)
          * `value` (`pulumi.Input[str]`)

        The **task_ebs_block_devices** object supports the following:

          * `iops` (`pulumi.Input[float]`)
          * `sizeInGb` (`pulumi.Input[float]`)
          * `volumeType` (`pulumi.Input[str]`)
          * `volumesPerInstance` (`pulumi.Input[float]`)

        The **task_scaling_down_policies** object supports the following:

          * `actionType` (`pulumi.Input[str]`)
          * `adjustment` (`pulumi.Input[str]`)
          * `cooldown` (`pulumi.Input[float]`)
          * `dimensions` (`pulumi.Input[dict]`)
          * `evaluationPeriods` (`pulumi.Input[float]`)
          * `maxTargetCapacity` (`pulumi.Input[str]`)
          * `maximum` (`pulumi.Input[str]`)
          * `metricName` (`pulumi.Input[str]`)
          * `minTargetCapacity` (`pulumi.Input[str]`)
          * `minimum` (`pulumi.Input[str]`)
          * `namespace` (`pulumi.Input[str]`)
          * `operator` (`pulumi.Input[str]`)
          * `period` (`pulumi.Input[float]`)
          * `policyName` (`pulumi.Input[str]`)
          * `statistic` (`pulumi.Input[str]`)
          * `target` (`pulumi.Input[str]`)
          * `threshold` (`pulumi.Input[float]`)
          * `unit` (`pulumi.Input[str]`)

        The **task_scaling_up_policies** object supports the following:

          * `actionType` (`pulumi.Input[str]`)
          * `adjustment` (`pulumi.Input[str]`)
          * `cooldown` (`pulumi.Input[float]`)
          * `dimensions` (`pulumi.Input[dict]`)
          * `evaluationPeriods` (`pulumi.Input[float]`)
          * `maxTargetCapacity` (`pulumi.Input[str]`)
          * `maximum` (`pulumi.Input[str]`)
          * `metricName` (`pulumi.Input[str]`)
          * `minTargetCapacity` (`pulumi.Input[str]`)
          * `minimum` (`pulumi.Input[str]`)
          * `namespace` (`pulumi.Input[str]`)
          * `operator` (`pulumi.Input[str]`)
          * `period` (`pulumi.Input[float]`)
          * `policyName` (`pulumi.Input[str]`)
          * `statistic` (`pulumi.Input[str]`)
          * `target` (`pulumi.Input[str]`)
          * `threshold` (`pulumi.Input[float]`)
          * `unit` (`pulumi.Input[str]`)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['additional_info'] = additional_info
            __props__['additional_primary_security_groups'] = additional_primary_security_groups
            __props__['additional_replica_security_groups'] = additional_replica_security_groups
            __props__['applications'] = applications
            __props__['availability_zones'] = availability_zones
            __props__['bootstrap_actions_files'] = bootstrap_actions_files
            __props__['cluster_id'] = cluster_id
            __props__['configurations_files'] = configurations_files
            __props__['core_desired_capacity'] = core_desired_capacity
            __props__['core_ebs_block_devices'] = core_ebs_block_devices
            __props__['core_ebs_optimized'] = core_ebs_optimized
            __props__['core_instance_types'] = core_instance_types
            __props__['core_lifecycle'] = core_lifecycle
            __props__['core_max_size'] = core_max_size
            __props__['core_min_size'] = core_min_size
            __props__['core_scaling_down_policies'] = core_scaling_down_policies
            __props__['core_scaling_up_policies'] = core_scaling_up_policies
            __props__['custom_ami_id'] = custom_ami_id
            __props__['description'] = description
            __props__['ebs_root_volume_size'] = ebs_root_volume_size
            __props__['ec2_key_name'] = ec2_key_name
            __props__['expose_cluster_id'] = expose_cluster_id
            __props__['instance_weights'] = instance_weights
            __props__['job_flow_role'] = job_flow_role
            __props__['keep_job_flow_alive'] = keep_job_flow_alive
            __props__['log_uri'] = log_uri
            __props__['managed_primary_security_group'] = managed_primary_security_group
            __props__['managed_replica_security_group'] = managed_replica_security_group
            __props__['master_ebs_block_devices'] = master_ebs_block_devices
            __props__['master_ebs_optimized'] = master_ebs_optimized
            __props__['master_instance_types'] = master_instance_types
            __props__['master_lifecycle'] = master_lifecycle
            __props__['name'] = name
            __props__['provisioning_timeout'] = provisioning_timeout
            __props__['region'] = region
            __props__['release_label'] = release_label
            __props__['repo_upgrade_on_boot'] = repo_upgrade_on_boot
            __props__['retries'] = retries
            __props__['scheduled_tasks'] = scheduled_tasks
            __props__['security_config'] = security_config
            __props__['service_access_security_group'] = service_access_security_group
            __props__['service_role'] = service_role
            __props__['steps_files'] = steps_files
            if strategy is None:
                raise TypeError("Missing required property 'strategy'")
            __props__['strategy'] = strategy
            __props__['tags'] = tags
            __props__['task_desired_capacity'] = task_desired_capacity
            __props__['task_ebs_block_devices'] = task_ebs_block_devices
            __props__['task_ebs_optimized'] = task_ebs_optimized
            __props__['task_instance_types'] = task_instance_types
            __props__['task_lifecycle'] = task_lifecycle
            __props__['task_max_size'] = task_max_size
            __props__['task_min_size'] = task_min_size
            __props__['task_scaling_down_policies'] = task_scaling_down_policies
            __props__['task_scaling_up_policies'] = task_scaling_up_policies
            __props__['termination_protected'] = termination_protected
            __props__['visible_to_all_users'] = visible_to_all_users
            __props__['output_cluster_id'] = None
        super(MrScalar, __self__).__init__(
            'spotinst:aws/mrScalar:MrScalar',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, additional_info=None, additional_primary_security_groups=None, additional_replica_security_groups=None, applications=None, availability_zones=None, bootstrap_actions_files=None, cluster_id=None, configurations_files=None, core_desired_capacity=None, core_ebs_block_devices=None, core_ebs_optimized=None, core_instance_types=None, core_lifecycle=None, core_max_size=None, core_min_size=None, core_scaling_down_policies=None, core_scaling_up_policies=None, custom_ami_id=None, description=None, ebs_root_volume_size=None, ec2_key_name=None, expose_cluster_id=None, instance_weights=None, job_flow_role=None, keep_job_flow_alive=None, log_uri=None, managed_primary_security_group=None, managed_replica_security_group=None, master_ebs_block_devices=None, master_ebs_optimized=None, master_instance_types=None, master_lifecycle=None, name=None, output_cluster_id=None, provisioning_timeout=None, region=None, release_label=None, repo_upgrade_on_boot=None, retries=None, scheduled_tasks=None, security_config=None, service_access_security_group=None, service_role=None, steps_files=None, strategy=None, tags=None, task_desired_capacity=None, task_ebs_block_devices=None, task_ebs_optimized=None, task_instance_types=None, task_lifecycle=None, task_max_size=None, task_min_size=None, task_scaling_down_policies=None, task_scaling_up_policies=None, termination_protected=None, visible_to_all_users=None):
        """
        Get an existing MrScalar resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cluster_id: The MrScaler cluster id.
        :param pulumi.Input[str] description: The MrScaler description.
        :param pulumi.Input[str] name: The MrScaler name.
        :param pulumi.Input[str] region: The MrScaler region.
        :param pulumi.Input[str] strategy: The MrScaler strategy. Allowed values are `new` `clone` and `wrap`.

        The **applications** object supports the following:

          * `args` (`pulumi.Input[list]`)
          * `name` (`pulumi.Input[str]`) - The MrScaler name.
          * `version` (`pulumi.Input[str]`)

        The **bootstrap_actions_files** object supports the following:

          * `bucket` (`pulumi.Input[str]`)
          * `key` (`pulumi.Input[str]`)

        The **configurations_files** object supports the following:

          * `bucket` (`pulumi.Input[str]`)
          * `key` (`pulumi.Input[str]`)

        The **core_ebs_block_devices** object supports the following:

          * `iops` (`pulumi.Input[float]`)
          * `sizeInGb` (`pulumi.Input[float]`)
          * `volumeType` (`pulumi.Input[str]`)
          * `volumesPerInstance` (`pulumi.Input[float]`)

        The **core_scaling_down_policies** object supports the following:

          * `actionType` (`pulumi.Input[str]`)
          * `adjustment` (`pulumi.Input[str]`)
          * `cooldown` (`pulumi.Input[float]`)
          * `dimensions` (`pulumi.Input[dict]`)
          * `evaluationPeriods` (`pulumi.Input[float]`)
          * `maxTargetCapacity` (`pulumi.Input[str]`)
          * `maximum` (`pulumi.Input[str]`)
          * `metricName` (`pulumi.Input[str]`)
          * `minTargetCapacity` (`pulumi.Input[str]`)
          * `minimum` (`pulumi.Input[str]`)
          * `namespace` (`pulumi.Input[str]`)
          * `operator` (`pulumi.Input[str]`)
          * `period` (`pulumi.Input[float]`)
          * `policyName` (`pulumi.Input[str]`)
          * `statistic` (`pulumi.Input[str]`)
          * `target` (`pulumi.Input[str]`)
          * `threshold` (`pulumi.Input[float]`)
          * `unit` (`pulumi.Input[str]`)

        The **core_scaling_up_policies** object supports the following:

          * `actionType` (`pulumi.Input[str]`)
          * `adjustment` (`pulumi.Input[str]`)
          * `cooldown` (`pulumi.Input[float]`)
          * `dimensions` (`pulumi.Input[dict]`)
          * `evaluationPeriods` (`pulumi.Input[float]`)
          * `maxTargetCapacity` (`pulumi.Input[str]`)
          * `maximum` (`pulumi.Input[str]`)
          * `metricName` (`pulumi.Input[str]`)
          * `minTargetCapacity` (`pulumi.Input[str]`)
          * `minimum` (`pulumi.Input[str]`)
          * `namespace` (`pulumi.Input[str]`)
          * `operator` (`pulumi.Input[str]`)
          * `period` (`pulumi.Input[float]`)
          * `policyName` (`pulumi.Input[str]`)
          * `statistic` (`pulumi.Input[str]`)
          * `target` (`pulumi.Input[str]`)
          * `threshold` (`pulumi.Input[float]`)
          * `unit` (`pulumi.Input[str]`)

        The **instance_weights** object supports the following:

          * `instanceType` (`pulumi.Input[str]`)
          * `weightedCapacity` (`pulumi.Input[float]`)

        The **master_ebs_block_devices** object supports the following:

          * `iops` (`pulumi.Input[float]`)
          * `sizeInGb` (`pulumi.Input[float]`)
          * `volumeType` (`pulumi.Input[str]`)
          * `volumesPerInstance` (`pulumi.Input[float]`)

        The **provisioning_timeout** object supports the following:

          * `timeout` (`pulumi.Input[float]`)
          * `timeoutAction` (`pulumi.Input[str]`)

        The **scheduled_tasks** object supports the following:

          * `cron` (`pulumi.Input[str]`)
          * `desired_capacity` (`pulumi.Input[str]`)
          * `instanceGroupType` (`pulumi.Input[str]`)
          * `isEnabled` (`pulumi.Input[bool]`)
          * `maxCapacity` (`pulumi.Input[str]`)
          * `minCapacity` (`pulumi.Input[str]`)
          * `taskType` (`pulumi.Input[str]`)

        The **steps_files** object supports the following:

          * `bucket` (`pulumi.Input[str]`)
          * `key` (`pulumi.Input[str]`)

        The **tags** object supports the following:

          * `key` (`pulumi.Input[str]`)
          * `value` (`pulumi.Input[str]`)

        The **task_ebs_block_devices** object supports the following:

          * `iops` (`pulumi.Input[float]`)
          * `sizeInGb` (`pulumi.Input[float]`)
          * `volumeType` (`pulumi.Input[str]`)
          * `volumesPerInstance` (`pulumi.Input[float]`)

        The **task_scaling_down_policies** object supports the following:

          * `actionType` (`pulumi.Input[str]`)
          * `adjustment` (`pulumi.Input[str]`)
          * `cooldown` (`pulumi.Input[float]`)
          * `dimensions` (`pulumi.Input[dict]`)
          * `evaluationPeriods` (`pulumi.Input[float]`)
          * `maxTargetCapacity` (`pulumi.Input[str]`)
          * `maximum` (`pulumi.Input[str]`)
          * `metricName` (`pulumi.Input[str]`)
          * `minTargetCapacity` (`pulumi.Input[str]`)
          * `minimum` (`pulumi.Input[str]`)
          * `namespace` (`pulumi.Input[str]`)
          * `operator` (`pulumi.Input[str]`)
          * `period` (`pulumi.Input[float]`)
          * `policyName` (`pulumi.Input[str]`)
          * `statistic` (`pulumi.Input[str]`)
          * `target` (`pulumi.Input[str]`)
          * `threshold` (`pulumi.Input[float]`)
          * `unit` (`pulumi.Input[str]`)

        The **task_scaling_up_policies** object supports the following:

          * `actionType` (`pulumi.Input[str]`)
          * `adjustment` (`pulumi.Input[str]`)
          * `cooldown` (`pulumi.Input[float]`)
          * `dimensions` (`pulumi.Input[dict]`)
          * `evaluationPeriods` (`pulumi.Input[float]`)
          * `maxTargetCapacity` (`pulumi.Input[str]`)
          * `maximum` (`pulumi.Input[str]`)
          * `metricName` (`pulumi.Input[str]`)
          * `minTargetCapacity` (`pulumi.Input[str]`)
          * `minimum` (`pulumi.Input[str]`)
          * `namespace` (`pulumi.Input[str]`)
          * `operator` (`pulumi.Input[str]`)
          * `period` (`pulumi.Input[float]`)
          * `policyName` (`pulumi.Input[str]`)
          * `statistic` (`pulumi.Input[str]`)
          * `target` (`pulumi.Input[str]`)
          * `threshold` (`pulumi.Input[float]`)
          * `unit` (`pulumi.Input[str]`)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["additional_info"] = additional_info
        __props__["additional_primary_security_groups"] = additional_primary_security_groups
        __props__["additional_replica_security_groups"] = additional_replica_security_groups
        __props__["applications"] = applications
        __props__["availability_zones"] = availability_zones
        __props__["bootstrap_actions_files"] = bootstrap_actions_files
        __props__["cluster_id"] = cluster_id
        __props__["configurations_files"] = configurations_files
        __props__["core_desired_capacity"] = core_desired_capacity
        __props__["core_ebs_block_devices"] = core_ebs_block_devices
        __props__["core_ebs_optimized"] = core_ebs_optimized
        __props__["core_instance_types"] = core_instance_types
        __props__["core_lifecycle"] = core_lifecycle
        __props__["core_max_size"] = core_max_size
        __props__["core_min_size"] = core_min_size
        __props__["core_scaling_down_policies"] = core_scaling_down_policies
        __props__["core_scaling_up_policies"] = core_scaling_up_policies
        __props__["custom_ami_id"] = custom_ami_id
        __props__["description"] = description
        __props__["ebs_root_volume_size"] = ebs_root_volume_size
        __props__["ec2_key_name"] = ec2_key_name
        __props__["expose_cluster_id"] = expose_cluster_id
        __props__["instance_weights"] = instance_weights
        __props__["job_flow_role"] = job_flow_role
        __props__["keep_job_flow_alive"] = keep_job_flow_alive
        __props__["log_uri"] = log_uri
        __props__["managed_primary_security_group"] = managed_primary_security_group
        __props__["managed_replica_security_group"] = managed_replica_security_group
        __props__["master_ebs_block_devices"] = master_ebs_block_devices
        __props__["master_ebs_optimized"] = master_ebs_optimized
        __props__["master_instance_types"] = master_instance_types
        __props__["master_lifecycle"] = master_lifecycle
        __props__["name"] = name
        __props__["output_cluster_id"] = output_cluster_id
        __props__["provisioning_timeout"] = provisioning_timeout
        __props__["region"] = region
        __props__["release_label"] = release_label
        __props__["repo_upgrade_on_boot"] = repo_upgrade_on_boot
        __props__["retries"] = retries
        __props__["scheduled_tasks"] = scheduled_tasks
        __props__["security_config"] = security_config
        __props__["service_access_security_group"] = service_access_security_group
        __props__["service_role"] = service_role
        __props__["steps_files"] = steps_files
        __props__["strategy"] = strategy
        __props__["tags"] = tags
        __props__["task_desired_capacity"] = task_desired_capacity
        __props__["task_ebs_block_devices"] = task_ebs_block_devices
        __props__["task_ebs_optimized"] = task_ebs_optimized
        __props__["task_instance_types"] = task_instance_types
        __props__["task_lifecycle"] = task_lifecycle
        __props__["task_max_size"] = task_max_size
        __props__["task_min_size"] = task_min_size
        __props__["task_scaling_down_policies"] = task_scaling_down_policies
        __props__["task_scaling_up_policies"] = task_scaling_up_policies
        __props__["termination_protected"] = termination_protected
        __props__["visible_to_all_users"] = visible_to_all_users
        return MrScalar(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Elastigroup(pulumi.CustomResource):
    auto_healing: pulumi.Output[bool]
    availability_zones: pulumi.Output[list]
    """
    List of availability zones for the group.
    """
    backend_services: pulumi.Output[list]
    description: pulumi.Output[str]
    """
    The region your GCP group will be created in.
    """
    desired_capacity: pulumi.Output[float]
    """
    The desired number of instances the group should have at any time.
    """
    disks: pulumi.Output[list]
    draining_timeout: pulumi.Output[float]
    """
    Time (seconds) the instance is allowed to run after it is detached from the group. This is to allow the instance time to drain all the current TCP connections before terminating it.
    """
    fallback_to_ondemand: pulumi.Output[bool]
    """
    Activate fallback-to-on-demand. When provisioning an instance, if no Preemptible market is available, fallback-to-on-demand will provision an On-Demand instance to maintain the group capacity.
    """
    gpu: pulumi.Output[list]
    health_check_grace_period: pulumi.Output[float]
    health_check_type: pulumi.Output[str]
    instance_types_customs: pulumi.Output[list]
    """
    Defines a set of custom instance types. Required if instance_types_preemptible and instance_types_ondemand are not set.

      * `memoryGib` (`float`) - The memory (in GiB) in the custom instance types. GCP has a number of limitations on accepted memory values.For more information, see the GCP documentation (here.)[https://cloud.google.com/compute/docs/instances/creating-instance-with-custom-machine-type#specifications]
      * `vcpu` (`float`)
    """
    instance_types_ondemand: pulumi.Output[str]
    """
    The regular VM instance type to use for mixed-type groups and when falling back to on-demand. Required if instance_types_preemptible is not set.
    """
    instance_types_preemptibles: pulumi.Output[list]
    """
    The preemptible VMs instance type. To maximize cost savings and market availability, select as many types as possible. Required if instance_types_ondemand is not set.
    """
    integration_docker_swarm: pulumi.Output[dict]
    integration_gke: pulumi.Output[dict]
    ip_forwarding: pulumi.Output[bool]
    labels: pulumi.Output[list]
    """
    Array of objects with key-value pairs.

      * `key` (`str`) - Labels key.
      * `value` (`str`) - Labels value.
    """
    max_size: pulumi.Output[float]
    """
    The maximum number of instances the group should have at any time.
    """
    metadatas: pulumi.Output[list]
    """
    Array of objects with key-value pairs.

      * `key` (`str`) - Labels key.
      * `value` (`str`) - Labels value.
    """
    min_size: pulumi.Output[float]
    """
    The minimum number of instances the group should have at any time.
    """
    name: pulumi.Output[str]
    """
    The group name. 
    """
    network_interfaces: pulumi.Output[list]
    ondemand_count: pulumi.Output[float]
    preemptible_percentage: pulumi.Output[float]
    """
    Percentage of Preemptible VMs to spin up from the "desired_capacity".
    """
    scaling_down_policies: pulumi.Output[list]
    scaling_up_policies: pulumi.Output[list]
    scheduled_tasks: pulumi.Output[list]
    service_account: pulumi.Output[str]
    """
    The email of the service account in which the group instances will be launched.
    """
    shutdown_script: pulumi.Output[str]
    """
    The Base64-encoded shutdown script that executes prior to instance termination, for more information please see: [Shutdown Script](https://api.spotinst.com/integration-docs/elastigroup/concepts/compute-concepts/shutdown-scripts/)
    """
    startup_script: pulumi.Output[str]
    """
    Create and run your own startup scripts on your virtual machines to perform automated tasks every time your instance boots up.
    """
    subnets: pulumi.Output[list]
    """
    A list of regions and subnets.

      * `region` (`str`) - The region for the group of subnets.
      * `subnetNames` (`list`) - The names of the subnets in the region.
    """
    tags: pulumi.Output[list]
    """
    Tags to mark created instances.
    """
    unhealthy_duration: pulumi.Output[float]
    def __init__(__self__, resource_name, opts=None, auto_healing=None, availability_zones=None, backend_services=None, description=None, desired_capacity=None, disks=None, draining_timeout=None, fallback_to_ondemand=None, gpu=None, health_check_grace_period=None, health_check_type=None, instance_types_customs=None, instance_types_ondemand=None, instance_types_preemptibles=None, integration_docker_swarm=None, integration_gke=None, ip_forwarding=None, labels=None, max_size=None, metadatas=None, min_size=None, name=None, network_interfaces=None, ondemand_count=None, preemptible_percentage=None, scaling_down_policies=None, scaling_up_policies=None, scheduled_tasks=None, service_account=None, shutdown_script=None, startup_script=None, subnets=None, tags=None, unhealthy_duration=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Spotinst elastigroup GCP resource.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-spotinst/blob/master/website/docs/r/elastigroup_gcp.html.markdown.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] availability_zones: List of availability zones for the group.
        :param pulumi.Input[str] description: The region your GCP group will be created in.
        :param pulumi.Input[float] desired_capacity: The desired number of instances the group should have at any time.
        :param pulumi.Input[float] draining_timeout: Time (seconds) the instance is allowed to run after it is detached from the group. This is to allow the instance time to drain all the current TCP connections before terminating it.
        :param pulumi.Input[bool] fallback_to_ondemand: Activate fallback-to-on-demand. When provisioning an instance, if no Preemptible market is available, fallback-to-on-demand will provision an On-Demand instance to maintain the group capacity.
        :param pulumi.Input[list] instance_types_customs: Defines a set of custom instance types. Required if instance_types_preemptible and instance_types_ondemand are not set.
        :param pulumi.Input[str] instance_types_ondemand: The regular VM instance type to use for mixed-type groups and when falling back to on-demand. Required if instance_types_preemptible is not set.
        :param pulumi.Input[list] instance_types_preemptibles: The preemptible VMs instance type. To maximize cost savings and market availability, select as many types as possible. Required if instance_types_ondemand is not set.
        :param pulumi.Input[list] labels: Array of objects with key-value pairs.
        :param pulumi.Input[float] max_size: The maximum number of instances the group should have at any time.
        :param pulumi.Input[list] metadatas: Array of objects with key-value pairs.
        :param pulumi.Input[float] min_size: The minimum number of instances the group should have at any time.
        :param pulumi.Input[str] name: The group name. 
        :param pulumi.Input[float] preemptible_percentage: Percentage of Preemptible VMs to spin up from the "desired_capacity".
        :param pulumi.Input[str] service_account: The email of the service account in which the group instances will be launched.
        :param pulumi.Input[str] shutdown_script: The Base64-encoded shutdown script that executes prior to instance termination, for more information please see: [Shutdown Script](https://api.spotinst.com/integration-docs/elastigroup/concepts/compute-concepts/shutdown-scripts/)
        :param pulumi.Input[str] startup_script: Create and run your own startup scripts on your virtual machines to perform automated tasks every time your instance boots up.
        :param pulumi.Input[list] subnets: A list of regions and subnets.
        :param pulumi.Input[list] tags: Tags to mark created instances.

        The **backend_services** object supports the following:

          * `locationType` (`pulumi.Input[str]`)
          * `namedPorts` (`pulumi.Input[list]`)
            * `name` (`pulumi.Input[str]`) - The group name. 
            * `ports` (`pulumi.Input[list]`)

          * `scheme` (`pulumi.Input[str]`)
          * `serviceName` (`pulumi.Input[str]`)

        The **disks** object supports the following:

          * `autoDelete` (`pulumi.Input[bool]`)
          * `boot` (`pulumi.Input[bool]`)
          * `deviceName` (`pulumi.Input[str]`)
          * `initializeParams` (`pulumi.Input[list]`)
            * `diskSizeGb` (`pulumi.Input[str]`)
            * `diskType` (`pulumi.Input[str]`)
            * `source_image` (`pulumi.Input[str]`)

          * `interface` (`pulumi.Input[str]`)
          * `mode` (`pulumi.Input[str]`)
          * `source` (`pulumi.Input[str]`)
          * `type` (`pulumi.Input[str]`)

        The **gpu** object supports the following:

          * `count` (`pulumi.Input[float]`)
          * `type` (`pulumi.Input[str]`)

        The **instance_types_customs** object supports the following:

          * `memoryGib` (`pulumi.Input[float]`) - The memory (in GiB) in the custom instance types. GCP has a number of limitations on accepted memory values.For more information, see the GCP documentation (here.)[https://cloud.google.com/compute/docs/instances/creating-instance-with-custom-machine-type#specifications]
          * `vcpu` (`pulumi.Input[float]`)

        The **integration_docker_swarm** object supports the following:

          * `masterHost` (`pulumi.Input[str]`)
          * `masterPort` (`pulumi.Input[float]`)

        The **integration_gke** object supports the following:

          * `autoUpdate` (`pulumi.Input[bool]`)
          * `autoscaleCooldown` (`pulumi.Input[float]`)
          * `autoscaleDown` (`pulumi.Input[dict]`)
            * `evaluationPeriods` (`pulumi.Input[float]`)

          * `autoscaleHeadroom` (`pulumi.Input[dict]`)
            * `cpuPerUnit` (`pulumi.Input[float]`)
            * `memoryPerUnit` (`pulumi.Input[float]`)
            * `numOfUnits` (`pulumi.Input[float]`)

          * `autoscaleIsAutoConfig` (`pulumi.Input[bool]`)
          * `autoscaleIsEnabled` (`pulumi.Input[bool]`)
          * `autoscaleLabels` (`pulumi.Input[list]`)
            * `key` (`pulumi.Input[str]`) - Labels key.
            * `value` (`pulumi.Input[str]`) - Labels value.

          * `cluster_id` (`pulumi.Input[str]`)
          * `location` (`pulumi.Input[str]`)

        The **labels** object supports the following:

          * `key` (`pulumi.Input[str]`) - Labels key.
          * `value` (`pulumi.Input[str]`) - Labels value.

        The **metadatas** object supports the following:

          * `key` (`pulumi.Input[str]`) - Labels key.
          * `value` (`pulumi.Input[str]`) - Labels value.

        The **network_interfaces** object supports the following:

          * `accessConfigs` (`pulumi.Input[list]`)
            * `name` (`pulumi.Input[str]`) - The group name. 
            * `type` (`pulumi.Input[str]`)

          * `aliasIpRanges` (`pulumi.Input[list]`)
            * `ipCidrRange` (`pulumi.Input[str]`)
            * `subnetworkRangeName` (`pulumi.Input[str]`)

          * `network` (`pulumi.Input[str]`)

        The **scaling_down_policies** object supports the following:

          * `actionType` (`pulumi.Input[str]`)
          * `adjustment` (`pulumi.Input[float]`)
          * `cooldown` (`pulumi.Input[float]`)
          * `dimensions` (`pulumi.Input[list]`)
            * `name` (`pulumi.Input[str]`) - The group name. 
            * `value` (`pulumi.Input[str]`) - Labels value.

          * `evaluationPeriods` (`pulumi.Input[float]`)
          * `metricName` (`pulumi.Input[str]`)
          * `namespace` (`pulumi.Input[str]`)
          * `operator` (`pulumi.Input[str]`)
          * `period` (`pulumi.Input[float]`)
          * `policyName` (`pulumi.Input[str]`)
          * `source` (`pulumi.Input[str]`)
          * `statistic` (`pulumi.Input[str]`)
          * `threshold` (`pulumi.Input[float]`)
          * `unit` (`pulumi.Input[str]`)

        The **scaling_up_policies** object supports the following:

          * `actionType` (`pulumi.Input[str]`)
          * `adjustment` (`pulumi.Input[float]`)
          * `cooldown` (`pulumi.Input[float]`)
          * `dimensions` (`pulumi.Input[list]`)
            * `name` (`pulumi.Input[str]`) - The group name. 
            * `value` (`pulumi.Input[str]`) - Labels value.

          * `evaluationPeriods` (`pulumi.Input[float]`)
          * `metricName` (`pulumi.Input[str]`)
          * `namespace` (`pulumi.Input[str]`)
          * `operator` (`pulumi.Input[str]`)
          * `period` (`pulumi.Input[float]`)
          * `policyName` (`pulumi.Input[str]`)
          * `source` (`pulumi.Input[str]`)
          * `statistic` (`pulumi.Input[str]`)
          * `threshold` (`pulumi.Input[float]`)
          * `unit` (`pulumi.Input[str]`)

        The **scheduled_tasks** object supports the following:

          * `cronExpression` (`pulumi.Input[str]`)
          * `isEnabled` (`pulumi.Input[bool]`)
          * `maxCapacity` (`pulumi.Input[str]`)
          * `minCapacity` (`pulumi.Input[str]`)
          * `targetCapacity` (`pulumi.Input[str]`)
          * `taskType` (`pulumi.Input[str]`)

        The **subnets** object supports the following:

          * `region` (`pulumi.Input[str]`) - The region for the group of subnets.
          * `subnetNames` (`pulumi.Input[list]`) - The names of the subnets in the region.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['auto_healing'] = auto_healing
            __props__['availability_zones'] = availability_zones
            __props__['backend_services'] = backend_services
            __props__['description'] = description
            if desired_capacity is None:
                raise TypeError("Missing required property 'desired_capacity'")
            __props__['desired_capacity'] = desired_capacity
            __props__['disks'] = disks
            __props__['draining_timeout'] = draining_timeout
            __props__['fallback_to_ondemand'] = fallback_to_ondemand
            __props__['gpu'] = gpu
            __props__['health_check_grace_period'] = health_check_grace_period
            __props__['health_check_type'] = health_check_type
            __props__['instance_types_customs'] = instance_types_customs
            __props__['instance_types_ondemand'] = instance_types_ondemand
            __props__['instance_types_preemptibles'] = instance_types_preemptibles
            __props__['integration_docker_swarm'] = integration_docker_swarm
            __props__['integration_gke'] = integration_gke
            __props__['ip_forwarding'] = ip_forwarding
            __props__['labels'] = labels
            __props__['max_size'] = max_size
            __props__['metadatas'] = metadatas
            __props__['min_size'] = min_size
            __props__['name'] = name
            __props__['network_interfaces'] = network_interfaces
            __props__['ondemand_count'] = ondemand_count
            __props__['preemptible_percentage'] = preemptible_percentage
            __props__['scaling_down_policies'] = scaling_down_policies
            __props__['scaling_up_policies'] = scaling_up_policies
            __props__['scheduled_tasks'] = scheduled_tasks
            __props__['service_account'] = service_account
            __props__['shutdown_script'] = shutdown_script
            __props__['startup_script'] = startup_script
            __props__['subnets'] = subnets
            __props__['tags'] = tags
            __props__['unhealthy_duration'] = unhealthy_duration
        super(Elastigroup, __self__).__init__(
            'spotinst:gcp/elastigroup:Elastigroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, auto_healing=None, availability_zones=None, backend_services=None, description=None, desired_capacity=None, disks=None, draining_timeout=None, fallback_to_ondemand=None, gpu=None, health_check_grace_period=None, health_check_type=None, instance_types_customs=None, instance_types_ondemand=None, instance_types_preemptibles=None, integration_docker_swarm=None, integration_gke=None, ip_forwarding=None, labels=None, max_size=None, metadatas=None, min_size=None, name=None, network_interfaces=None, ondemand_count=None, preemptible_percentage=None, scaling_down_policies=None, scaling_up_policies=None, scheduled_tasks=None, service_account=None, shutdown_script=None, startup_script=None, subnets=None, tags=None, unhealthy_duration=None):
        """
        Get an existing Elastigroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] availability_zones: List of availability zones for the group.
        :param pulumi.Input[str] description: The region your GCP group will be created in.
        :param pulumi.Input[float] desired_capacity: The desired number of instances the group should have at any time.
        :param pulumi.Input[float] draining_timeout: Time (seconds) the instance is allowed to run after it is detached from the group. This is to allow the instance time to drain all the current TCP connections before terminating it.
        :param pulumi.Input[bool] fallback_to_ondemand: Activate fallback-to-on-demand. When provisioning an instance, if no Preemptible market is available, fallback-to-on-demand will provision an On-Demand instance to maintain the group capacity.
        :param pulumi.Input[list] instance_types_customs: Defines a set of custom instance types. Required if instance_types_preemptible and instance_types_ondemand are not set.
        :param pulumi.Input[str] instance_types_ondemand: The regular VM instance type to use for mixed-type groups and when falling back to on-demand. Required if instance_types_preemptible is not set.
        :param pulumi.Input[list] instance_types_preemptibles: The preemptible VMs instance type. To maximize cost savings and market availability, select as many types as possible. Required if instance_types_ondemand is not set.
        :param pulumi.Input[list] labels: Array of objects with key-value pairs.
        :param pulumi.Input[float] max_size: The maximum number of instances the group should have at any time.
        :param pulumi.Input[list] metadatas: Array of objects with key-value pairs.
        :param pulumi.Input[float] min_size: The minimum number of instances the group should have at any time.
        :param pulumi.Input[str] name: The group name. 
        :param pulumi.Input[float] preemptible_percentage: Percentage of Preemptible VMs to spin up from the "desired_capacity".
        :param pulumi.Input[str] service_account: The email of the service account in which the group instances will be launched.
        :param pulumi.Input[str] shutdown_script: The Base64-encoded shutdown script that executes prior to instance termination, for more information please see: [Shutdown Script](https://api.spotinst.com/integration-docs/elastigroup/concepts/compute-concepts/shutdown-scripts/)
        :param pulumi.Input[str] startup_script: Create and run your own startup scripts on your virtual machines to perform automated tasks every time your instance boots up.
        :param pulumi.Input[list] subnets: A list of regions and subnets.
        :param pulumi.Input[list] tags: Tags to mark created instances.

        The **backend_services** object supports the following:

          * `locationType` (`pulumi.Input[str]`)
          * `namedPorts` (`pulumi.Input[list]`)
            * `name` (`pulumi.Input[str]`) - The group name. 
            * `ports` (`pulumi.Input[list]`)

          * `scheme` (`pulumi.Input[str]`)
          * `serviceName` (`pulumi.Input[str]`)

        The **disks** object supports the following:

          * `autoDelete` (`pulumi.Input[bool]`)
          * `boot` (`pulumi.Input[bool]`)
          * `deviceName` (`pulumi.Input[str]`)
          * `initializeParams` (`pulumi.Input[list]`)
            * `diskSizeGb` (`pulumi.Input[str]`)
            * `diskType` (`pulumi.Input[str]`)
            * `source_image` (`pulumi.Input[str]`)

          * `interface` (`pulumi.Input[str]`)
          * `mode` (`pulumi.Input[str]`)
          * `source` (`pulumi.Input[str]`)
          * `type` (`pulumi.Input[str]`)

        The **gpu** object supports the following:

          * `count` (`pulumi.Input[float]`)
          * `type` (`pulumi.Input[str]`)

        The **instance_types_customs** object supports the following:

          * `memoryGib` (`pulumi.Input[float]`) - The memory (in GiB) in the custom instance types. GCP has a number of limitations on accepted memory values.For more information, see the GCP documentation (here.)[https://cloud.google.com/compute/docs/instances/creating-instance-with-custom-machine-type#specifications]
          * `vcpu` (`pulumi.Input[float]`)

        The **integration_docker_swarm** object supports the following:

          * `masterHost` (`pulumi.Input[str]`)
          * `masterPort` (`pulumi.Input[float]`)

        The **integration_gke** object supports the following:

          * `autoUpdate` (`pulumi.Input[bool]`)
          * `autoscaleCooldown` (`pulumi.Input[float]`)
          * `autoscaleDown` (`pulumi.Input[dict]`)
            * `evaluationPeriods` (`pulumi.Input[float]`)

          * `autoscaleHeadroom` (`pulumi.Input[dict]`)
            * `cpuPerUnit` (`pulumi.Input[float]`)
            * `memoryPerUnit` (`pulumi.Input[float]`)
            * `numOfUnits` (`pulumi.Input[float]`)

          * `autoscaleIsAutoConfig` (`pulumi.Input[bool]`)
          * `autoscaleIsEnabled` (`pulumi.Input[bool]`)
          * `autoscaleLabels` (`pulumi.Input[list]`)
            * `key` (`pulumi.Input[str]`) - Labels key.
            * `value` (`pulumi.Input[str]`) - Labels value.

          * `cluster_id` (`pulumi.Input[str]`)
          * `location` (`pulumi.Input[str]`)

        The **labels** object supports the following:

          * `key` (`pulumi.Input[str]`) - Labels key.
          * `value` (`pulumi.Input[str]`) - Labels value.

        The **metadatas** object supports the following:

          * `key` (`pulumi.Input[str]`) - Labels key.
          * `value` (`pulumi.Input[str]`) - Labels value.

        The **network_interfaces** object supports the following:

          * `accessConfigs` (`pulumi.Input[list]`)
            * `name` (`pulumi.Input[str]`) - The group name. 
            * `type` (`pulumi.Input[str]`)

          * `aliasIpRanges` (`pulumi.Input[list]`)
            * `ipCidrRange` (`pulumi.Input[str]`)
            * `subnetworkRangeName` (`pulumi.Input[str]`)

          * `network` (`pulumi.Input[str]`)

        The **scaling_down_policies** object supports the following:

          * `actionType` (`pulumi.Input[str]`)
          * `adjustment` (`pulumi.Input[float]`)
          * `cooldown` (`pulumi.Input[float]`)
          * `dimensions` (`pulumi.Input[list]`)
            * `name` (`pulumi.Input[str]`) - The group name. 
            * `value` (`pulumi.Input[str]`) - Labels value.

          * `evaluationPeriods` (`pulumi.Input[float]`)
          * `metricName` (`pulumi.Input[str]`)
          * `namespace` (`pulumi.Input[str]`)
          * `operator` (`pulumi.Input[str]`)
          * `period` (`pulumi.Input[float]`)
          * `policyName` (`pulumi.Input[str]`)
          * `source` (`pulumi.Input[str]`)
          * `statistic` (`pulumi.Input[str]`)
          * `threshold` (`pulumi.Input[float]`)
          * `unit` (`pulumi.Input[str]`)

        The **scaling_up_policies** object supports the following:

          * `actionType` (`pulumi.Input[str]`)
          * `adjustment` (`pulumi.Input[float]`)
          * `cooldown` (`pulumi.Input[float]`)
          * `dimensions` (`pulumi.Input[list]`)
            * `name` (`pulumi.Input[str]`) - The group name. 
            * `value` (`pulumi.Input[str]`) - Labels value.

          * `evaluationPeriods` (`pulumi.Input[float]`)
          * `metricName` (`pulumi.Input[str]`)
          * `namespace` (`pulumi.Input[str]`)
          * `operator` (`pulumi.Input[str]`)
          * `period` (`pulumi.Input[float]`)
          * `policyName` (`pulumi.Input[str]`)
          * `source` (`pulumi.Input[str]`)
          * `statistic` (`pulumi.Input[str]`)
          * `threshold` (`pulumi.Input[float]`)
          * `unit` (`pulumi.Input[str]`)

        The **scheduled_tasks** object supports the following:

          * `cronExpression` (`pulumi.Input[str]`)
          * `isEnabled` (`pulumi.Input[bool]`)
          * `maxCapacity` (`pulumi.Input[str]`)
          * `minCapacity` (`pulumi.Input[str]`)
          * `targetCapacity` (`pulumi.Input[str]`)
          * `taskType` (`pulumi.Input[str]`)

        The **subnets** object supports the following:

          * `region` (`pulumi.Input[str]`) - The region for the group of subnets.
          * `subnetNames` (`pulumi.Input[list]`) - The names of the subnets in the region.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["auto_healing"] = auto_healing
        __props__["availability_zones"] = availability_zones
        __props__["backend_services"] = backend_services
        __props__["description"] = description
        __props__["desired_capacity"] = desired_capacity
        __props__["disks"] = disks
        __props__["draining_timeout"] = draining_timeout
        __props__["fallback_to_ondemand"] = fallback_to_ondemand
        __props__["gpu"] = gpu
        __props__["health_check_grace_period"] = health_check_grace_period
        __props__["health_check_type"] = health_check_type
        __props__["instance_types_customs"] = instance_types_customs
        __props__["instance_types_ondemand"] = instance_types_ondemand
        __props__["instance_types_preemptibles"] = instance_types_preemptibles
        __props__["integration_docker_swarm"] = integration_docker_swarm
        __props__["integration_gke"] = integration_gke
        __props__["ip_forwarding"] = ip_forwarding
        __props__["labels"] = labels
        __props__["max_size"] = max_size
        __props__["metadatas"] = metadatas
        __props__["min_size"] = min_size
        __props__["name"] = name
        __props__["network_interfaces"] = network_interfaces
        __props__["ondemand_count"] = ondemand_count
        __props__["preemptible_percentage"] = preemptible_percentage
        __props__["scaling_down_policies"] = scaling_down_policies
        __props__["scaling_up_policies"] = scaling_up_policies
        __props__["scheduled_tasks"] = scheduled_tasks
        __props__["service_account"] = service_account
        __props__["shutdown_script"] = shutdown_script
        __props__["startup_script"] = startup_script
        __props__["subnets"] = subnets
        __props__["tags"] = tags
        __props__["unhealthy_duration"] = unhealthy_duration
        return Elastigroup(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

